import React from 'react';
import { ICognitoLoginProps } from './ICognitoLoginProps';
import { ICognitoLoginState } from './ICognitoLoginState';
/**
 * A form for logging in to AWS Cognito through Amplify.
 *
 * On successful login the {@link ICognitoLoginProps.onLoggedIn} event is triggered.
 *
 * Remarks:
 * * Requires Amplify to be configured:
 *
 * https://aws-amplify.github.io/docs/js/start?ref=amplify-rn-btn&platform=react-native#step-4-integrate-aws-resources
 *
 * Props are {@link ICognitoLoginProps}
 *
 * @example
 *  <CognitoLogin
 *    onLoggedIn={(user) => console.log(user)}
 *     loginButtonProps={{title: 'Engage'}}>
 *     <Text>Custom layouts here</Text>
 *  </CognitoLogin>
 */
export declare class CognitoLogin extends React.Component<ICognitoLoginProps, ICognitoLoginState> {
    constructor(props: ICognitoLoginProps);
    onResultChanged: () => void;
    onEmailChanged: (email: string | undefined) => void;
    onPasswordChanged: (password: string | undefined) => void;
    onPhoneChanged: (phone: string | undefined) => void;
    OnResendSignup: () => void;
    onRegister: () => Promise<void>;
    onConfirmAccount: () => Promise<void>;
    onConfirmMFACode: () => Promise<void>;
    onLogin: () => Promise<void>;
    render(): JSX.Element;
}
export default CognitoLogin;
//# sourceMappingURL=CognitoLogin.d.ts.map